@@ -23,6 +23,8 @@ from .onex_fabricapi import FabricQosProfilePacketClassification
 from .onex_fabricapi import FabricQosProfilePacketClassificationMap
 from .onex_fabricapi import FabricQosProfileIter
 from .onex_fabricapi import ErrorDetails
+from .onex_fabricapi import ErrorItem
+from .onex_fabricapi import ErrorItemIter
 from .onex_fabricapi import Api
 from .onex_fabricapi import HttpApi
 from .onex_fabricapi import api
